@@ -249,4 +249,13 @@ public interface ClusterService {
      */
     @Service NetworkFiltersService networkFilters();
 
+    /**
+     * Reference to the service that manages the collection of enabled features for this cluster.
+     *
+     * @author Sahina Bose <sabose@redhat.com>
+     * @date 04 Aug 2017
+     * @status added
+     * @since 4.1.6
+     */
+    @Service ClusterEnabledFeaturesService enabledFeatures();
 }
