@@ -40,7 +40,7 @@ import org.ovirt.engine.sdk4.services.OpenstackImageProviderService;
 import org.ovirt.engine.sdk4.services.OpenstackImagesService;
 import org.ovirt.engine.sdk4.types.OpenStackImageProvider;
 
-public class OpenstackImageProviderServiceImpl extends ServiceImpl implements OpenstackImageProviderService {
+public class OpenstackImageProviderServiceImpl extends ExternalProviderServiceImpl implements OpenstackImageProviderService {
     
     public OpenstackImageProviderServiceImpl(HttpConnection connection, String path) {
         super(connection, path);
