@@ -42,7 +42,7 @@ import org.ovirt.engine.sdk4.types.StorageDomain;
 /**
  * A service to manage a host.
  */
-public interface HostService extends Service {
+public interface HostService extends MeasurableService {
     /**
      * Activate the host for use, such as running virtual machines.
      */
@@ -75,7 +75,15 @@ public interface HostService extends Service {
          */
         ApproveRequest async(Boolean async);
         ApproveRequest cluster(Cluster cluster);
+        /**
+         * Cluster where the host will be added after approving it.
+         */
         ApproveRequest cluster(ClusterBuilder cluster);
+        ApproveRequest host(Host host);
+        /**
+         * Host to approve.
+         */
+        ApproveRequest host(HostBuilder host);
     }
     
     /**
@@ -385,8 +393,31 @@ public interface HostService extends Service {
     
     /**
      * Get the host details.
+     * 
+     * [source]
+     * ----
+     * GET /ovirt-engine/api/hosts/123
+     * ----
      */
     public interface GetRequest extends Request<GetRequest, GetResponse> {
+        /**
+         * Indicates if all of the attributes of the host should be included in the response.
+         * 
+         * By default the following attributes are excluded:
+         * 
+         * - `hosted_engine`
+         * 
+         * For example, to retrieve the complete representation of host '123':
+         * 
+         * ....
+         * GET /ovirt-engine/api/hosts/123?all_content=true
+         * ....
+         * 
+         * NOTE: These attributes are not included by default because retrieving them impacts performance. They are
+         * seldom used and require additional queries to the database. Use this parameter with caution and only when
+         * specifically required.
+         */
+        GetRequest allContent(Boolean allContent);
         /**
          * Indicates if the results should be filtered according to the permissions of the user.
          */
@@ -395,13 +426,26 @@ public interface HostService extends Service {
     
     /**
      * Get the host details.
+     * 
+     * [source]
+     * ----
+     * GET /ovirt-engine/api/hosts/123
+     * ----
      */
     public interface GetResponse extends Response {
+        /**
+         * Queried host.
+         */
         Host host();
     }
     
     /**
      * Get the host details.
+     * 
+     * [source]
+     * ----
+     * GET /ovirt-engine/api/hosts/123
+     * ----
      */
     GetRequest get();
     
