@@ -35,7 +35,7 @@ import org.ovirt.engine.sdk4.types.StorageDomain;
 import org.ovirt.engine.sdk4.types.Ticket;
 import org.ovirt.engine.sdk4.types.Vm;
 
-public interface VmService extends Service {
+public interface VmService extends MeasurableService {
     /**
      * This operation stops any migration of a virtual machine to another physical host.
      * 
@@ -44,8 +44,8 @@ public interface VmService extends Service {
      * POST /ovirt-engine/api/vms/123/cancelmigration
      * ----
      * 
-     * The cancel migration action does not take any action specific parameters,
-     * so the request body should contain an empty `action`:
+     * The cancel migration action does not take any action specific parameters;
+     * therefore, the request body should contain an empty `action`:
      * 
      * [source,xml]
      * ----
@@ -67,8 +67,8 @@ public interface VmService extends Service {
      * POST /ovirt-engine/api/vms/123/cancelmigration
      * ----
      * 
-     * The cancel migration action does not take any action specific parameters,
-     * so the request body should contain an empty `action`:
+     * The cancel migration action does not take any action specific parameters;
+     * therefore, the request body should contain an empty `action`:
      * 
      * [source,xml]
      * ----
@@ -86,8 +86,8 @@ public interface VmService extends Service {
      * POST /ovirt-engine/api/vms/123/cancelmigration
      * ----
      * 
-     * The cancel migration action does not take any action specific parameters,
-     * so the request body should contain an empty `action`:
+     * The cancel migration action does not take any action specific parameters;
+     * therefore, the request body should contain an empty `action`:
      * 
      * [source,xml]
      * ----
@@ -110,6 +110,11 @@ public interface VmService extends Service {
     
     CloneRequest clone_();
     
+    /**
+     * Permanently restores the virtual machine to the state of the previewed snapshot.
+     * 
+     * See the <<services/vm/methods/preview_snapshot, preview_snapshot>> operation for details.
+     */
     public interface CommitSnapshotRequest extends Request<CommitSnapshotRequest, CommitSnapshotResponse> {
         /**
          * Indicates if the snapshots should be committed asynchronously.
@@ -117,9 +122,19 @@ public interface VmService extends Service {
         CommitSnapshotRequest async(Boolean async);
     }
     
+    /**
+     * Permanently restores the virtual machine to the state of the previewed snapshot.
+     * 
+     * See the <<services/vm/methods/preview_snapshot, preview_snapshot>> operation for details.
+     */
     public interface CommitSnapshotResponse extends Response {
     }
     
+    /**
+     * Permanently restores the virtual machine to the state of the previewed snapshot.
+     * 
+     * See the <<services/vm/methods/preview_snapshot, preview_snapshot>> operation for details.
+     */
     CommitSnapshotRequest commitSnapshot();
     
     /**
@@ -130,7 +145,7 @@ public interface VmService extends Service {
      * POST /ovirt-engine/api/vms/123/detach
      * ----
      * 
-     * The detach action does not take any action specific parameters, so the request body should contain an
+     * The detach action does not take any action specific parameters; therefore, the request body should contain an
      * empty `action`:
      * 
      * [source,xml]
@@ -140,7 +155,7 @@ public interface VmService extends Service {
      */
     public interface DetachRequest extends Request<DetachRequest, DetachResponse> {
         /**
-         * Indicates if the detach should be performed asynchronously.
+         * Indicates if the detach action should be performed asynchronously.
          */
         DetachRequest async(Boolean async);
     }
@@ -153,7 +168,7 @@ public interface VmService extends Service {
      * POST /ovirt-engine/api/vms/123/detach
      * ----
      * 
-     * The detach action does not take any action specific parameters, so the request body should contain an
+     * The detach action does not take any action specific parameters; therefore, the request body should contain an
      * empty `action`:
      * 
      * [source,xml]
@@ -172,7 +187,7 @@ public interface VmService extends Service {
      * POST /ovirt-engine/api/vms/123/detach
      * ----
      * 
-     * The detach action does not take any action specific parameters, so the request body should contain an
+     * The detach action does not take any action specific parameters; therefore, the request body should contain an
      * empty `action`:
      * 
      * [source,xml]
@@ -183,9 +198,9 @@ public interface VmService extends Service {
     DetachRequest detach();
     
     /**
-     * Export a virtual machine to an export domain.
+     * Exports a virtual machine to an export domain.
      * 
-     * For example to export virtual machine `123` to the export domain `myexport`, send a request like this:
+     * For example, to export virtual machine `123` to the export domain `myexport`:
      * 
      * [source]
      * ----
@@ -211,12 +226,12 @@ public interface VmService extends Service {
          */
         ExportRequest async(Boolean async);
         /**
-         * The `discard_snapshots` parameter is to be used when the virtual machine should be exported with all its
+         * Use the `discard_snapshots` parameter when the virtual machine should be exported with all of its
          * snapshots collapsed.
          */
         ExportRequest discardSnapshots(Boolean discardSnapshots);
         /**
-         * The `exclusive` parameter is to be used when the virtual machine should be exported even if another copy of
+         * Use the `exclusive` parameter when the virtual machine should be exported even if another copy of
          * it already exists in the export domain (override).
          */
         ExportRequest exclusive(Boolean exclusive);
@@ -225,9 +240,9 @@ public interface VmService extends Service {
     }
     
     /**
-     * Export a virtual machine to an export domain.
+     * Exports a virtual machine to an export domain.
      * 
-     * For example to export virtual machine `123` to the export domain `myexport`, send a request like this:
+     * For example, to export virtual machine `123` to the export domain `myexport`:
      * 
      * [source]
      * ----
@@ -251,9 +266,9 @@ public interface VmService extends Service {
     }
     
     /**
-     * Export a virtual machine to an export domain.
+     * Exports a virtual machine to an export domain.
      * 
-     * For example to export virtual machine `123` to the export domain `myexport`, send a request like this:
+     * For example, to export virtual machine `123` to the export domain `myexport`:
      * 
      * [source]
      * ----
@@ -276,7 +291,7 @@ public interface VmService extends Service {
     ExportRequest export();
     
     /**
-     * Freeze virtual machine file systems.
+     * Freezes virtual machine file systems.
      * 
      * This operation freezes a virtual machine's file systems using the QEMU guest agent when taking a live snapshot of
      * a running virtual machine. Normally, this is done automatically by the manager, but this must be executed
@@ -302,7 +317,7 @@ public interface VmService extends Service {
     }
     
     /**
-     * Freeze virtual machine file systems.
+     * Freezes virtual machine file systems.
      * 
      * This operation freezes a virtual machine's file systems using the QEMU guest agent when taking a live snapshot of
      * a running virtual machine. Normally, this is done automatically by the manager, but this must be executed
@@ -324,7 +339,7 @@ public interface VmService extends Service {
     }
     
     /**
-     * Freeze virtual machine file systems.
+     * Freezes virtual machine file systems.
      * 
      * This operation freezes a virtual machine's file systems using the QEMU guest agent when taking a live snapshot of
      * a running virtual machine. Normally, this is done automatically by the manager, but this must be executed
@@ -349,7 +364,7 @@ public interface VmService extends Service {
      */
     public interface GetRequest extends Request<GetRequest, GetResponse> {
         /**
-         * Indicates if all the attributes of the virtual machine should be included in the response.
+         * Indicates if all of the attributes of the virtual machine should be included in the response.
          * 
          * By default the following attributes are excluded:
          * 
@@ -359,14 +374,14 @@ public interface VmService extends Service {
          * - `soundcard`
          * - `virtio_scsi`
          * 
-         * For example, to retrieve the complete representation of the virtual machine '123' send a request like this:
+         * For example, to retrieve the complete representation of the virtual machine '123':
          * 
          * ....
          * GET /ovirt-engine/api/vms/123?all_content=true
          * ....
          * 
-         * NOTE: The reason for not including these attributes is performance: they are seldom used and they require
-         * additional queries to the database. So try to use the this parameter only when it is really needed.
+         * NOTE: These attributes are not included by default as they reduce performance. These attributes are seldom used
+         * and require additional queries to the database. Only use this parameter when required as it will reduce performance.
          */
         GetRequest allContent(Boolean allContent);
         /**
@@ -374,11 +389,11 @@ public interface VmService extends Service {
          */
         GetRequest filter(Boolean filter);
         /**
-         * Indicates if the returned result describes the virtual machine as it is currently running, or if describes
-         * it with the modifications that have already been performed but that will have effect only when it is
-         * restarted. By default the values is `false`.
+         * Indicates if the returned result describes the virtual machine as it is currently running or if describes
+         * the virtual machine with the modifications that have already been performed but that will only come into
+         * effect when the virtual machine is restarted. By default the value is `false`.
          * 
-         * If the parameter is included in the request, but without a value, it is assumed that the value is `true`, so
+         * If the parameter is included in the request, but without a value, it is assumed that the value is `true`. The
          * the following request:
          * 
          * [source]
@@ -420,7 +435,7 @@ public interface VmService extends Service {
      * Users require the appropriate user permissions for the virtual machine in order to access the virtual machine
      * from an external console.
      * 
-     * This is how an example request would look like:
+     * For example:
      * 
      * [source]
      * ----
@@ -450,7 +465,7 @@ public interface VmService extends Service {
      * Users require the appropriate user permissions for the virtual machine in order to access the virtual machine
      * from an external console.
      * 
-     * This is how an example request would look like:
+     * For example:
      * 
      * [source]
      * ----
@@ -476,7 +491,7 @@ public interface VmService extends Service {
      * Users require the appropriate user permissions for the virtual machine in order to access the virtual machine
      * from an external console.
      * 
-     * This is how an example request would look like:
+     * For example:
      * 
      * [source]
      * ----
@@ -513,7 +528,7 @@ public interface VmService extends Service {
      */
     public interface MaintenanceRequest extends Request<MaintenanceRequest, MaintenanceResponse> {
         /**
-         * Indicates if the action should be performed asynchronously.
+         * Indicates if the global maintenance action should be performed asynchronously.
          */
         MaintenanceRequest async(Boolean async);
         /**
@@ -566,14 +581,16 @@ public interface VmService extends Service {
     MaintenanceRequest maintenance();
     
     /**
-     * This operation migrates a virtual machine to another physical host.
+     * Migrates a virtual machine to another physical host.
+     * 
+     * Example:
      * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/migrate
      * ----
      * 
-     * One can specify a specific host to migrate the virtual machine to:
+     * To specify a specific host to migrate the virtual machine to:
      * 
      * [source,xml]
      * ----
@@ -594,28 +611,30 @@ public interface VmService extends Service {
          */
         MigrateRequest cluster(ClusterBuilder cluster);
         /**
-         * Specifies the virtual machine should migrate although it might be defined as non migratable. This is an
-         * optional parameter. By default, it is set to `false`.
+         * Specifies that the virtual machine should migrate even if the virtual machine is defined as non-migratable.
+         * This is an optional parameter. By default, it is set to `false`.
          */
         MigrateRequest force(Boolean force);
         MigrateRequest host(Host host);
         /**
-         * Specifies a specific host the virtual machine should migrate to. This is an optional parameters. By default,
-         * the oVirt Engine automatically selects a default host for migration within the same cluster. If an API user
+         * Specifies a specific host that the virtual machine should migrate to. This is an optional parameter. By default,
+         * the {engine-name} automatically selects a default host for migration within the same cluster. If an API user
          * requires a specific host, the user can specify the host with either an `id` or `name` parameter.
          */
         MigrateRequest host(HostBuilder host);
     }
     
     /**
-     * This operation migrates a virtual machine to another physical host.
+     * Migrates a virtual machine to another physical host.
+     * 
+     * Example:
      * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/migrate
      * ----
      * 
-     * One can specify a specific host to migrate the virtual machine to:
+     * To specify a specific host to migrate the virtual machine to:
      * 
      * [source,xml]
      * ----
@@ -628,14 +647,16 @@ public interface VmService extends Service {
     }
     
     /**
-     * This operation migrates a virtual machine to another physical host.
+     * Migrates a virtual machine to another physical host.
+     * 
+     * Example:
      * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/migrate
      * ----
      * 
-     * One can specify a specific host to migrate the virtual machine to:
+     * To specify a specific host to migrate the virtual machine to:
      * 
      * [source,xml]
      * ----
@@ -646,6 +667,14 @@ public interface VmService extends Service {
      */
     MigrateRequest migrate();
     
+    /**
+     * Temporarily restores the virtual machine to the state of a snapshot.
+     * 
+     * The snapshot is indicated with the `snapshot.id` parameter. It is restored temporarily, so that the content can
+     * be inspected. Once that inspection is finished, the state of the virtual machine can be made permanent, using the
+     * <<services/vm/methods/commit_snapshot, commit_snapshot>> method, or discarded using the
+     * <<services/vm/methods/undo_snapshot, undo_snapshot>> method.
+     */
     public interface PreviewSnapshotRequest extends Request<PreviewSnapshotRequest, PreviewSnapshotResponse> {
         /**
          * Indicates if the preview should be performed asynchronously.
@@ -661,20 +690,38 @@ public interface VmService extends Service {
         PreviewSnapshotRequest vm(VmBuilder vm);
     }
     
+    /**
+     * Temporarily restores the virtual machine to the state of a snapshot.
+     * 
+     * The snapshot is indicated with the `snapshot.id` parameter. It is restored temporarily, so that the content can
+     * be inspected. Once that inspection is finished, the state of the virtual machine can be made permanent, using the
+     * <<services/vm/methods/commit_snapshot, commit_snapshot>> method, or discarded using the
+     * <<services/vm/methods/undo_snapshot, undo_snapshot>> method.
+     */
     public interface PreviewSnapshotResponse extends Response {
     }
     
+    /**
+     * Temporarily restores the virtual machine to the state of a snapshot.
+     * 
+     * The snapshot is indicated with the `snapshot.id` parameter. It is restored temporarily, so that the content can
+     * be inspected. Once that inspection is finished, the state of the virtual machine can be made permanent, using the
+     * <<services/vm/methods/commit_snapshot, commit_snapshot>> method, or discarded using the
+     * <<services/vm/methods/undo_snapshot, undo_snapshot>> method.
+     */
     PreviewSnapshotRequest previewSnapshot();
     
     /**
-     * This operation sends a reboot request to a virtual machine.
+     * Sends a reboot request to a virtual machine.
+     * 
+     * For example:
      * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/reboot
      * ----
      * 
-     * The reboot action does not take any action specific parameters, so the request body should contain an
+     * The reboot action does not take any action specific parameters; therefore, the request body should contain an
      * empty `action`:
      * 
      * [source,xml]
@@ -690,14 +737,16 @@ public interface VmService extends Service {
     }
     
     /**
-     * This operation sends a reboot request to a virtual machine.
+     * Sends a reboot request to a virtual machine.
+     * 
+     * For example:
      * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/reboot
      * ----
      * 
-     * The reboot action does not take any action specific parameters, so the request body should contain an
+     * The reboot action does not take any action specific parameters; therefore, the request body should contain an
      * empty `action`:
      * 
      * [source,xml]
@@ -709,14 +758,16 @@ public interface VmService extends Service {
     }
     
     /**
-     * This operation sends a reboot request to a virtual machine.
+     * Sends a reboot request to a virtual machine.
+     * 
+     * For example:
      * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/reboot
      * ----
      * 
-     * The reboot action does not take any action specific parameters, so the request body should contain an
+     * The reboot action does not take any action specific parameters; therefore, the request body should contain an
      * empty `action`:
      * 
      * [source,xml]
@@ -729,7 +780,7 @@ public interface VmService extends Service {
     /**
      * Removes the virtual machine, including the virtual disks attached to it.
      * 
-     * For example, to remove the virtual machine with identifier `123` send a request like this:
+     * For example, to remove the virtual machine with identifier `123`:
      * 
      * [source]
      * ----
@@ -757,7 +808,7 @@ public interface VmService extends Service {
     /**
      * Removes the virtual machine, including the virtual disks attached to it.
      * 
-     * For example, to remove the virtual machine with identifier `123` send a request like this:
+     * For example, to remove the virtual machine with identifier `123`:
      * 
      * [source]
      * ----
@@ -770,7 +821,7 @@ public interface VmService extends Service {
     /**
      * Removes the virtual machine, including the virtual disks attached to it.
      * 
-     * For example, to remove the virtual machine with identifier `123` send a request like this:
+     * For example, to remove the virtual machine with identifier `123`:
      * 
      * [source]
      * ----
@@ -794,13 +845,15 @@ public interface VmService extends Service {
     /**
      * This operation sends a shutdown request to a virtual machine.
      * 
+     * For example:
+     * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/shutdown
      * ----
      * 
-     * The shutdown action does not take any action specific parameters,
-     * so the request body should contain an empty `action`:
+     * The shutdown action does not take any action specific parameters;
+     * therefore, the request body should contain an empty `action`:
      * 
      * [source,xml]
      * ----
@@ -817,13 +870,15 @@ public interface VmService extends Service {
     /**
      * This operation sends a shutdown request to a virtual machine.
      * 
+     * For example:
+     * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/shutdown
      * ----
      * 
-     * The shutdown action does not take any action specific parameters,
-     * so the request body should contain an empty `action`:
+     * The shutdown action does not take any action specific parameters;
+     * therefore, the request body should contain an empty `action`:
      * 
      * [source,xml]
      * ----
@@ -836,13 +891,15 @@ public interface VmService extends Service {
     /**
      * This operation sends a shutdown request to a virtual machine.
      * 
+     * For example:
+     * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/shutdown
      * ----
      * 
-     * The shutdown action does not take any action specific parameters,
-     * so the request body should contain an empty `action`:
+     * The shutdown action does not take any action specific parameters;
+     * therefore, the request body should contain an empty `action`:
      * 
      * [source,xml]
      * ----
@@ -873,7 +930,7 @@ public interface VmService extends Service {
      */
     public interface StartRequest extends Request<StartRequest, StartResponse> {
         /**
-         * Indicates if the action should be performed asynchronously.
+         * Indicates if the start action should be performed asynchronously.
          */
         StartRequest async(Boolean async);
         /**
@@ -881,7 +938,7 @@ public interface VmService extends Service {
          */
         StartRequest filter(Boolean filter);
         /**
-         * If set to `true`, start the virtual machine in paused mode. Default is `false`.
+         * If set to `true`, start the virtual machine in paused mode. The default is `false`.
          */
         StartRequest pause(Boolean pause);
         /**
@@ -915,7 +972,7 @@ public interface VmService extends Service {
          * </action>
          * ----
          * 
-         * This will set the boot device to the CDROM only for this specific start. After the virtual machine will be
+         * This will set the boot device to the CDROM only for this specific start. After the virtual machine is
          * powered off, this definition will be reverted.
          */
         StartRequest vm(VmBuilder vm);
@@ -969,13 +1026,15 @@ public interface VmService extends Service {
     /**
      * This operation forces a virtual machine to power-off.
      * 
+     * For example:
+     * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/stop
      * ----
      * 
-     * The stop action does not take any action specific parameters,
-     * so the request body should contain an empty `action`:
+     * The stop action does not take any action specific parameters;
+     * therefore, the request body should contain an empty `action`:
      * 
      * [source,xml]
      * ----
@@ -984,7 +1043,7 @@ public interface VmService extends Service {
      */
     public interface StopRequest extends Request<StopRequest, StopResponse> {
         /**
-         * Indicates if the action should be performed asynchronously.
+         * Indicates if the stop action should be performed asynchronously.
          */
         StopRequest async(Boolean async);
     }
@@ -992,13 +1051,15 @@ public interface VmService extends Service {
     /**
      * This operation forces a virtual machine to power-off.
      * 
+     * For example:
+     * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/stop
      * ----
      * 
-     * The stop action does not take any action specific parameters,
-     * so the request body should contain an empty `action`:
+     * The stop action does not take any action specific parameters;
+     * therefore, the request body should contain an empty `action`:
      * 
      * [source,xml]
      * ----
@@ -1011,13 +1072,15 @@ public interface VmService extends Service {
     /**
      * This operation forces a virtual machine to power-off.
      * 
+     * For example:
+     * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/stop
      * ----
      * 
-     * The stop action does not take any action specific parameters,
-     * so the request body should contain an empty `action`:
+     * The stop action does not take any action specific parameters;
+     * therefore, the request body should contain an empty `action`:
      * 
      * [source,xml]
      * ----
@@ -1030,13 +1093,15 @@ public interface VmService extends Service {
      * This operation saves the virtual machine state to disk and stops it.
      * Start a suspended virtual machine and restore the virtual machine state with the start action.
      * 
+     * For example:
+     * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/suspend
      * ----
      * 
-     * The suspend action does not take any action specific parameters,
-     * so the request body should contain an empty `action`:
+     * The suspend action does not take any action specific parameters;
+     * therefore, the request body should contain an empty `action`:
      * 
      * [source,xml]
      * ----
@@ -1045,7 +1110,7 @@ public interface VmService extends Service {
      */
     public interface SuspendRequest extends Request<SuspendRequest, SuspendResponse> {
         /**
-         * Indicates if the action should be performed asynchronously.
+         * Indicates if the suspend action should be performed asynchronously.
          */
         SuspendRequest async(Boolean async);
     }
@@ -1054,13 +1119,15 @@ public interface VmService extends Service {
      * This operation saves the virtual machine state to disk and stops it.
      * Start a suspended virtual machine and restore the virtual machine state with the start action.
      * 
+     * For example:
+     * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/suspend
      * ----
      * 
-     * The suspend action does not take any action specific parameters,
-     * so the request body should contain an empty `action`:
+     * The suspend action does not take any action specific parameters;
+     * therefore, the request body should contain an empty `action`:
      * 
      * [source,xml]
      * ----
@@ -1074,13 +1141,15 @@ public interface VmService extends Service {
      * This operation saves the virtual machine state to disk and stops it.
      * Start a suspended virtual machine and restore the virtual machine state with the start action.
      * 
+     * For example:
+     * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/suspend
      * ----
      * 
-     * The suspend action does not take any action specific parameters,
-     * so the request body should contain an empty `action`:
+     * The suspend action does not take any action specific parameters;
+     * therefore, the request body should contain an empty `action`:
      * 
      * [source,xml]
      * ----
@@ -1090,7 +1159,7 @@ public interface VmService extends Service {
     SuspendRequest suspend();
     
     /**
-     * Thaw virtual machine file systems.
+     * Thaws virtual machine file systems.
      * 
      * This operation thaws a virtual machine's file systems using the QEMU guest agent when taking a live snapshot of a
      * running virtual machine. Normally, this is done automatically by the manager, but this must be executed manually
@@ -1110,13 +1179,13 @@ public interface VmService extends Service {
      */
     public interface ThawFilesystemsRequest extends Request<ThawFilesystemsRequest, ThawFilesystemsResponse> {
         /**
-         * Indicates if the action should be performed asynchronously.
+         * Indicates if the thaw file systems action should be performed asynchronously.
          */
         ThawFilesystemsRequest async(Boolean async);
     }
     
     /**
-     * Thaw virtual machine file systems.
+     * Thaws virtual machine file systems.
      * 
      * This operation thaws a virtual machine's file systems using the QEMU guest agent when taking a live snapshot of a
      * running virtual machine. Normally, this is done automatically by the manager, but this must be executed manually
@@ -1138,7 +1207,7 @@ public interface VmService extends Service {
     }
     
     /**
-     * Thaw virtual machine file systems.
+     * Thaws virtual machine file systems.
      * 
      * This operation thaws a virtual machine's file systems using the QEMU guest agent when taking a live snapshot of a
      * running virtual machine. Normally, this is done automatically by the manager, but this must be executed manually
@@ -1161,6 +1230,8 @@ public interface VmService extends Service {
     /**
      * Generates a time-sensitive authentication token for accessing a virtual machine's display.
      * 
+     * For example:
+     * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/ticket
@@ -1168,7 +1239,7 @@ public interface VmService extends Service {
      * 
      * The client-provided action optionally includes a desired ticket value and/or an expiry time in seconds.
      * 
-     * In any case, the response specifies the actual ticket value and expiry used.
+     * The response specifies the actual ticket value and expiry used.
      * 
      * [source,xml]
      * ----
@@ -1190,8 +1261,8 @@ public interface VmService extends Service {
      * 
      * In order to obtain an authentication token for a specific protocol, for
      * example for VNC, use the `ticket` method of the <<services/vm_graphics_console,
-     * service>> that manages the graphics consoles of the virtual machine, sending
-     * a request like this:
+     * service>>, which manages the graphics consoles of the virtual machine, by sending
+     * a request:
      * 
      * [source]
      * ----
@@ -1211,6 +1282,8 @@ public interface VmService extends Service {
     /**
      * Generates a time-sensitive authentication token for accessing a virtual machine's display.
      * 
+     * For example:
+     * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/ticket
@@ -1218,7 +1291,7 @@ public interface VmService extends Service {
      * 
      * The client-provided action optionally includes a desired ticket value and/or an expiry time in seconds.
      * 
-     * In any case, the response specifies the actual ticket value and expiry used.
+     * The response specifies the actual ticket value and expiry used.
      * 
      * [source,xml]
      * ----
@@ -1240,8 +1313,8 @@ public interface VmService extends Service {
      * 
      * In order to obtain an authentication token for a specific protocol, for
      * example for VNC, use the `ticket` method of the <<services/vm_graphics_console,
-     * service>> that manages the graphics consoles of the virtual machine, sending
-     * a request like this:
+     * service>>, which manages the graphics consoles of the virtual machine, by sending
+     * a request:
      * 
      * [source]
      * ----
@@ -1256,6 +1329,8 @@ public interface VmService extends Service {
     /**
      * Generates a time-sensitive authentication token for accessing a virtual machine's display.
      * 
+     * For example:
+     * 
      * [source]
      * ----
      * POST /ovirt-engine/api/vms/123/ticket
@@ -1263,7 +1338,7 @@ public interface VmService extends Service {
      * 
      * The client-provided action optionally includes a desired ticket value and/or an expiry time in seconds.
      * 
-     * In any case, the response specifies the actual ticket value and expiry used.
+     * The response specifies the actual ticket value and expiry used.
      * 
      * [source,xml]
      * ----
@@ -1285,8 +1360,8 @@ public interface VmService extends Service {
      * 
      * In order to obtain an authentication token for a specific protocol, for
      * example for VNC, use the `ticket` method of the <<services/vm_graphics_console,
-     * service>> that manages the graphics consoles of the virtual machine, sending
-     * a request like this:
+     * service>>, which manages the graphics consoles of the virtual machine, by sending
+     * a request:
      * 
      * [source]
      * ----
@@ -1296,16 +1371,31 @@ public interface VmService extends Service {
      */
     TicketRequest ticket();
     
+    /**
+     * Restores the virtual machine to the state it had before previewing the snapshot.
+     * 
+     * See the <<services/vm/methods/preview_snapshot, preview_snapshot>> operation for details.
+     */
     public interface UndoSnapshotRequest extends Request<UndoSnapshotRequest, UndoSnapshotResponse> {
         /**
-         * Indicates if the action should be performed asynchronously.
+         * Indicates if the undo snapshot action should be performed asynchronously.
          */
         UndoSnapshotRequest async(Boolean async);
     }
     
+    /**
+     * Restores the virtual machine to the state it had before previewing the snapshot.
+     * 
+     * See the <<services/vm/methods/preview_snapshot, preview_snapshot>> operation for details.
+     */
     public interface UndoSnapshotResponse extends Response {
     }
     
+    /**
+     * Restores the virtual machine to the state it had before previewing the snapshot.
+     * 
+     * See the <<services/vm/methods/preview_snapshot, preview_snapshot>> operation for details.
+     */
     UndoSnapshotRequest undoSnapshot();
     
     public interface UpdateRequest extends Request<UpdateRequest, UpdateResponse> {
@@ -1314,7 +1404,7 @@ public interface VmService extends Service {
          */
         UpdateRequest async(Boolean async);
         /**
-         * Indicates if the update should be applied to the virtual machine immediately, or if it should be applied only
+         * Indicates if the update should be applied to the virtual machine immediately or if it should be applied only
          * when the virtual machine is restarted. The default value is `false`, so by default changes are applied
          * immediately.
          */
@@ -1330,7 +1420,7 @@ public interface VmService extends Service {
     UpdateRequest update();
     
     /**
-     * List of scheduling labels assigned to this VM.
+     * List of scheduling labels assigned to this virtual machine.
      */
     AssignedAffinityLabelsService affinityLabelsService();
     VmApplicationsService applicationsService();
