@@ -44,7 +44,7 @@ import org.ovirt.engine.sdk4.types.Action;
 import org.ovirt.engine.sdk4.types.Disk;
 import org.ovirt.engine.sdk4.types.StorageDomain;
 
-public class DiskServiceImpl extends ServiceImpl implements DiskService {
+public class DiskServiceImpl extends MeasurableServiceImpl implements DiskService {
     
     public DiskServiceImpl(HttpConnection connection, String path) {
         super(connection, path);
