@@ -40,7 +40,7 @@ import org.ovirt.engine.sdk4.services.OpenstackNetworkProviderService;
 import org.ovirt.engine.sdk4.services.OpenstackNetworksService;
 import org.ovirt.engine.sdk4.types.OpenStackNetworkProvider;
 
-public class OpenstackNetworkProviderServiceImpl extends ServiceImpl implements OpenstackNetworkProviderService {
+public class OpenstackNetworkProviderServiceImpl extends ExternalProviderServiceImpl implements OpenstackNetworkProviderService {
     
     public OpenstackNetworkProviderServiceImpl(HttpConnection connection, String path) {
         super(connection, path);
