@@ -24,7 +24,8 @@ public enum NfsVersion {
     AUTO,
     V3,
     V4,
-    V4_1;
+    V4_1,
+    V4_2;
     
     private static final Logger LOG = LoggerFactory.getLogger(NfsVersion.class);
     
@@ -37,7 +38,7 @@ public enum NfsVersion {
             return valueOf(value.toUpperCase());
         }
         catch (IllegalArgumentException e) {
-            LOG.error("The string '" + value + "' isn't a valid value for the 'NfsVersion' enumerated type. Valid values are: 'auto', 'v3', 'v4', 'v4_1'.");
+            LOG.error("The string '" + value + "' isn't a valid value for the 'NfsVersion' enumerated type. Valid values are: 'auto', 'v3', 'v4', 'v4_1', 'v4_2'.");
             return null;
         }
     }
